Function adview_manager::get_unit_html_with_events
source · pub fn get_unit_html_with_events(
options: &Options,
ad_unit: &AdUnit,
hostname: &str,
campaign_id: CampaignId,
validators: &Validators,
no_impression: bool
) -> StringExpand description
Generates the HTML for showing an Ad ([AdUnit]), as well as, the code for sending the events.
no_impression - whether or not an [IMPRESSION] event should be sent with onload.
WAIT_FOR_IMPRESSION- The time that needs to pass before sending the [IMPRESSION] event to all validators.